==> ultracopier_0.3.1.0.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Clean/Languages/ko/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko_KR">
<context>
    <name>InterfacePlugin</name>
    <message>
        <location filename="../../interface.cpp" line="+145"/>
        <source>%1/%2 files, %3/%4</source>
        <translation type="unfinished">%1/%2 파일, %3/%4</translation>
    </message>
</context>
<context>
    <name>interface</name>
    <message>
        <location filename="../../interface.ui" line="+32"/>
        <source>Action:</source>
        <translation type="unfinished">실행:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>In wait</source>
        <translation type="unfinished">대기중</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Add file</source>
        <translation type="unfinished">파일 추가</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add folder</source>
        <translation type="unfinished">폴더 추가</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move file(s)</source>
        <translation type="unfinished">파일 이동</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move folder</source>
        <translation type="unfinished">폴더 이동</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy file(s)</source>
        <translation type="unfinished">파일 복사</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy folder</source>
        <translation type="unfinished">폴더 복사</translation>
    </message>
</context>
</TS>

==> ultracopier_1.4.0.6.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Clean/Languages/ko/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>InterfacePlugin</name>
    <message>
        <location filename="../../interface.cpp" line="+142"/>
        <source>%1/%2 files, %3/%4</source>
        <translation type="unfinished">%1/%2 파일, %3/%4</translation>
    </message>
</context>
<context>
    <name>interface</name>
    <message>
        <location filename="../../interface.ui" line="+32"/>
        <source>Action:</source>
        <translation type="unfinished">실행:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Add file</source>
        <translation type="unfinished">파일 추가</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add folder</source>
        <translation type="unfinished">폴더 추가</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move file(s)</source>
        <translation type="unfinished">파일 이동</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move folder</source>
        <translation type="unfinished">폴더 이동</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy file(s)</source>
        <translation type="unfinished">파일 복사</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy folder</source>
        <translation type="unfinished">폴더 복사</translation>
    </message>
</context>
</TS>
